import { Module } from "@nestjs/common";
import { ConfigModule } from "@nestjs/config";
import { TypeOrmModule } from "@nestjs/typeorm";
import { AppController } from "./app.controller";
import { AppService } from "./app.service";
import { UsersRepository } from "./modules/users/user.repository";
import { UsersModule } from "./modules/users/users.module";
import { UsersService } from "./modules/users/users.service";
import { AuthModule } from "./modules/auth/auth.module";
import { JwtModule } from "@nestjs/jwt";
import { EmailNotifierModule } from "./modules/email-notifier/email-notifier.module";
import JwtConfigService from "./core/jwt/jwt-config.service";
import { MailerModule } from "@nestjs-modules/mailer";
import { HandlebarsAdapter } from "@nestjs-modules/mailer/dist/adapters/handlebars.adapter";
import { ServeStaticModule } from "@nestjs/serve-static";
import { join } from "path";
import { FileUploadsModule } from "./modules/file-uploads/file-uploads.module";
import { SendEmailModule } from "./modules/send-email/send-email.module";
import { SendEmailService } from "./modules/send-email/send-email.service";
import { SendEmailRepository } from "./modules/send-email/send-email-repository";
import { EmailNotifierRepository } from "./modules/email-notifier/email-notifier-repository";
import { FileUploadsService } from "./modules/file-uploads/file-uploads.service";
import { MailSenderModule } from "./modules/mail-sender/mail-sender.module";
import { SpacesModule } from "./modules/SpacesModule/spaces.module";
import { DoSpacesService } from "./modules/SpacesModule/SpacesService/doSpacesService";
import { DoSpacesServicerovider } from "./modules/SpacesModule/SpacesService";
import { BillingAddressModule } from "./modules/address/billing-address/billing-address.module";
import { ShippingAddressModule } from "./modules/address/shipping-address/shipping-address.module";
import { ContactPageCmsModule } from "./modules/CMS/contact-page-cms/contact-page-cms.module";
import { LandingPageCmsModule } from "./modules/CMS/landing-page-cms/landing-page-cms.module";
import { AboutPageCmsModule } from "./modules/CMS/about-page-cms/about-page-cms.module";
import { FAQPageCmsModule } from "./modules/CMS/faq-page-cms/faq-page-cms.module";
import { CareerPageCmsModule } from "./modules/CMS/career-page-cms/career-page-cms.module";
import { HeaderCmsModule } from "./modules/CMS/header-cms/header-cms.module";
import { FooterCmsModule } from "./modules/CMS/footer-cms/footer-cms.module";
import { HomePageSectionTwoCmsModule } from "./modules/CMS/home-page-section-two-cms/home-page-section-two-cms.module";
import {
    HomePageSectionThreeCmsModule
} from "./modules/CMS/home-page-section-three-cms/home-page-section-three-cms.module";
import {
    HomePageSectionFourCmsModule
} from "./modules/CMS/home-page-section-four-cms/home-page-section-four-cms.module";
import {
    HomePageCommonBannerCmsModule
} from "./modules/CMS/home-page-common-banner-cms/home-page-common-banner-cms.module";
import { NewDropBannerCmsModule } from "./modules/CMS/new-drop-banner-cms/new-drop-banner-cms.module";
import {
    HomePageSectionSevenCmsModule
} from "./modules/CMS/home-page-section-seven-cms/home-page-section-seven-cms.module";
import { PrivacyPolicyCmsModule } from "./modules/CMS/privacy-policy-cms/privacy-policy-cms.module";
import { TermsOfServiceCmsModule } from "./modules/CMS/terms-of-service-cms/terms-of-service-cms.module";
import { CookiesSettingsCmsModule } from "./modules/CMS/cookies-settings-cms/cookies-settings-cms.module";
import { StoreModule } from "./modules/store/store.module";
import { AboutPageSectionTwoModule } from "./modules/about-page-section-two/about-page-section-two.module";
import { HomePageSectionOneModule } from "./modules/home-page-section-one/home-page-section-one.module";
import { FAQModule } from "./modules/faq/faq.module";
import { CareerModule } from "./modules/career/career.module";
import { SocialPackModule } from "./modules/social-pack/social-pack.module";
import { CareerApplicantModule } from "./modules/career-applicant/career-applicant.module";
import { AboutPageUiModule } from "./modules/component-ui-cms/about-page-component-ui/about-page-ui.module";
import { CareerPageUiModule } from "./modules/component-ui-cms/career-page-component-ui/career-page-ui.module";
import {
    CareerDetailsPageUiModule
} from "./modules/component-ui-cms/career-details-page-component-ui/career-details-page-ui.module";
import { ContactPageUiModule } from "./modules/component-ui-cms/contact-page-component-ui/contact-page-ui.module";
import {
    CookiesSettingsPageUiModule
} from "./modules/component-ui-cms/cookies-settings-component-ui/cookies-settings-page-ui.module";
import {
    PrivacyPolicyPageUiModule
} from "./modules/component-ui-cms/privacy-policy-component-ui/privacy-policy-page-ui.module";
import {
    TermsConditionPageUiModule
} from "./modules/component-ui-cms/terms-condition-component-ui/terms-condition-page-ui.module";
import { SiteFrontendModule } from "./modules/site-frontend/site-frontend.module";
import { FaqPageUiModule } from "./modules/component-ui-cms/faq-page-component-ui/career-page-ui.module";
import { StoreCmsModule } from "./modules/store-cms/store-cms.module";
import { DutchiePlusCheckoutModule } from "./modules/dutchie-plus/dutchie-plus-checkout/dutchie-plus-checkout.module";
import { DutchiePlusProductModule } from "./modules/dutchie-plus/dutchie-plus-product/dutchie-plus-product.module";
import { DutchiePlusRetailerModule } from "./modules/dutchie-plus/dutchie-plus-retailer/dutchie-plus-retailer.module";
import { DutchiePlusSpecialsModule } from "./modules/dutchie-plus/dutchie-plus-specials/dutchie-plus-specials.module";
import { DutchiePlusOrderModule } from "./modules/dutchie-plus/dutchie-plus-order/dutchie-plus-order.module";
import { DutchiePlusCustomerModule } from "./modules/dutchie-plus/dutchie-plus-customer/dutchie-plus-customer.module";
import { BlogCategoryModule } from "./modules/blog/blog-category/blog-category.module";
import { BlogPostTagsModule } from "./modules/blog/blog-post-tags/blog-post-tags.module";
import { LandingPageUiModule } from "./modules/component-ui-cms/landing-page-component-ui/landing-page-ui.module";
import { ArticlePageUiModule } from "./modules/component-ui-cms/article-page-component-ui/article-page-ui.module";
import {
    ArticleDetailsPageUiModule
} from "./modules/component-ui-cms/article-details-page-component-ui/article-details-page-ui.module";
import { PressPageUiModule } from "./modules/component-ui-cms/press-page-component-ui/press-page-ui.module";
import {
    PressDetailsPageUiModule
} from "./modules/component-ui-cms/press-details-page-component-ui/press-details-page-ui.module";
import { AgeVerificationCmsModule } from "./modules/CMS/age-verification-cms/age-verification-cms.module";
import { FeedbackModule } from "./modules/feedback/feedback.module";
import { BlogTagModule } from "./modules/blog/blog-tag/blog-tag.module";
import { BlogPostModule } from "./modules/blog/blog-post/blog-post.module";
import { BlogRelatedPostsModule } from "./modules/blog/blog-related-posts/blog-related-posts.module";
import { PressReleaseModule } from "./modules/press-release/press-release.module";
import { ContactMessageModule } from "./modules/contact-message/contact-message.module";
import { ArticlePageCmsModule } from "./modules/CMS/article-page-cms/article-page-cms.module";
import { PressReleaseCmsModule } from "./modules/CMS/press-release-cms/press-release-cms.module";
import { ServiceTypeCmsModule } from "./modules/CMS/service-type-cms/service-type-cms.module";
import { CareerDepartmentModule } from "./modules/career-department/career-department.module";
import { CartCmsModule } from "./modules/CMS/cart-page-cms/cart-cms.module";
import { SchedulerModule } from "./modules/scheduler/scheduler.module";
import { ProductCategoryModule } from "./modules/dutchie-plus/custom-services/product-category/product-category.module";
import { QuizModule } from "./modules/quiz/quiz.module";
import { QuizPageCmsModule } from "./modules/CMS/quiz-page-cms/quiz-page-cms.module";
import {
    HomePageSectionEightCmsModule
} from "./modules/CMS/home-page-section-eight-cms/home-page-section-eight-cms.module";
import {
    HomePageSectionNineCmsModule
} from "./modules/CMS/home-page-section-nine-cms/home-page-section-nine-cms.module";
import {
    HomePageSectionFourSliderModule
} from "./modules/CMS/home-page-section-four-slider/home-page-section-four-slider.module";
import {
    HomePageSectionFiveCmsModule
} from "./modules/CMS/home-page-section-five-cms/home-page-section-five-cms.module";
import { HighDealsCmsModule } from "./modules/CMS/high-deals-cms/high-deals-cms.module";
import { DiscoverCmsModule } from "./modules/CMS/discover-cms/discover-cms.module";
import { ProductReviewModule } from "./modules/product-review/product-review.module";
import { ReserveTimeCmsModule } from "./modules/CMS/reserve-time-cms/reserve-time-cms.module";
import { RelatedProductCmsModule } from "./modules/CMS/related-product-cms/related-product-cms.module";
import { HowToEnjoyCmsModule } from "./modules/CMS/how-to-enjoy-cms/how-to-enjoy-cms.module";
import { ProductServiceModule } from "./modules/dutchie-plus/custom-services/product-service/product-service.module";
import { HomePageSectionTwoModule } from "./modules/home-page-section-two/home-page-section-two.module";
import { HomePageNewDropsBannerModule } from "./modules/home-page-new-drops-banner/home-page-new-drops-banner.module";
import { HomePageSectionEightModule } from "./modules/home-page-section-eight/home-page-section-eight.module";
import { HomePageSectionFiveModule } from "./modules/home-page-section-five/home-page-section-five.module";
import { FeaturedBrandModule } from "./modules/featured-brand/featured-brand.module";
import { RetailerServiceModule } from "./modules/dutchie-plus/custom-services/retailer-service/retailer-service.module";
import { OrderServiceModule } from "./modules/dutchie-plus/custom-services/order-service/order-service.module";
import { ArticleDetailsCmsModule } from "./modules/CMS/article-details-cms/article-details-cms.module";
import { SectionOneModule } from "./modules/CMS/section-one/section-one.module";
import { SectionTwoBottomModule } from "./modules/CMS/section-two-bottom/section-two-bottom.module";
import { SectionThreeModule } from "./modules/CMS/section-three/section-three.module";
import { SectionTwoTopModule } from "./modules/CMS/section-two-top/section-two-top.module";
import { AlpineiqModule } from "./modules/alpineiq/alpineiq.module";
import { PageTitleCmsModule } from "./modules/CMS/page-title-cms/page-title-cms.module";
import { PageMetaCmsModule } from "./modules/page-meta-cms/page-meta-cms.module";
import { HeaderBannerCmsModule } from "./modules/CMS/header-banner-cms/header-banner-cms.module";
import { InstagramSectionCmsModule } from "./modules/CMS/instagram-section-cms/instagram-section-cms.module";
import {
    ProductDetailsPageUiModule
} from "./modules/component-ui-cms/product-details-page-component-ui/product-details-page-ui.module";
import { StaticSiteMapCmsModule } from "./modules/CMS/static-site-map-cms/static-site-map-cms.module";
import { productDetailsPageMetaModule } from "./modules/CMS/product-details-page-meta/product-details-page-meta.module";
import { RobotCmsModule } from "./modules/CMS/robot-cms/robot-cms.module";
import { PageSchemaModule } from "./modules/CMS/page-schema/page-schema.module";
import { StepsSectionCmsModule } from "./modules/CMS/steps-section-cms/steps-section-cms.module";
import { BenefitsSectionCmsModule } from "./modules/CMS/benefits-section-cms/benefits-section-cms.module";
import { BenefitsModalModule } from "./modules/benefits-modal/benefits-modal.module";
import { AboutPageHeaderCmsModule } from "./modules/CMS/about-page-header-cms/about-page-header-cms.module";
import {
    AboutPageSectionTwoCmsModule
} from "./modules/CMS/about-page-section-two-cms/about-page-section-two-cms.module";
import {
    AboutPageSectionThreeCmsModule
} from "./modules/CMS/about-page-section-three-cms/about-page-section-three-cms.module";
import {
    AboutPageSectionOneCmsModule
} from "./modules/CMS/about-page-section-one-cms/about-page-section-one-cms.module";
import {
    TopTickerComponentUiModule
} from "./modules/component-ui-cms/top-ticker-component-ui/top-ticker-component-ui.module";
import {
    BenefitsSectionLearnMoreModule
} from "./modules/benefits-section-learn-more/benefits-section-learn-more.module";
import { BenefitsContentModule } from "./modules/benefits-content/benefits-content.module";
import { HomePageUiModule } from "./modules/component-ui-cms/home-page-component-ui/home-page-ui.module";
import { UserPageBannerCmsModule } from "./modules/CMS/user-page-banner-cms/user-page-banner-cms.module";
import {
    UserBannerComponentUiModule
} from "./modules/component-ui-cms/user-banner-component-ui/user-banner-component-ui.module";
import { HomePageSubNavModule } from "./modules/CMS/home-page-sub-nav/home-page-sub-nav.module";
import { ArticleCategoryModule } from "./modules/article-category/article-category.module";
import { PressReleaseCategoryModule } from "./modules/press-release-category/press-release-category.module";
import { ContactReasonModule } from "./modules/contact-reason/contact-reason.module";
import { JarsPlusPageUiModule } from "./modules/component-ui-cms/jars-plus-page-component-ui/jars-plus-page-ui.module";
import {
    StateWiseProductCategoryModule
} from "./modules/dutchie-plus/custom-services/state-wise-product-category/state-wise-product-category.module";
import { CartCounterCmsModule } from "./modules/CMS/cart-counter-cms/cart-counter-cms.module";
import { HomePageMobileCategoryCmsModule } from "./modules/CMS/home-page-mobile-category-cms/home-page-mobile-category-cms.module";
import { LoginPageCmsModule } from "./modules/CMS/login-page-cms/login-page-cms.module";
import { RegisterPageCmsModule } from "./modules/CMS/register-page-cms/register-page-cms.module";
import { LoginPageUiModule } from "./modules/component-ui-cms/login-page-component-ui/login-page-ui.module";
import { RegisterPageUiModule } from "./modules/component-ui-cms/register-page-component-ui/register-page-ui.module";
import { ShopPageBannerCmsModule } from "./modules/CMS/shop-page-banner-cms/shop-page-banner-cms.module";
import { ShopBannerComponentUiModule } from "./modules/component-ui-cms/shop-banner-component-ui/shop-banner-component-ui.module";
import { IheartjaneModule } from './modules/iheartjane/iheartjane.module';
import { PickupDeliveryCmsModule } from "./modules/CMS/pickup-delivery-cms/pickup-delivery-cms.module";

@Module({
    imports: [
        ServeStaticModule.forRoot({
            rootPath: join(__dirname, "..", "uploads")
        }),
        ConfigModule.forRoot({ isGlobal: true }),
        TypeOrmModule.forRoot({
            type: "mysql",
            host: process.env.HOST,
            port: parseInt(process.env.PORT),
            username: process.env.USERNAME,
            // username: 'root',
            password: process.env.PASSWORD,
            database: process.env.DATABASE,
            autoLoadEntities: true,
            synchronize: true,
            dropSchema: false
        }),
        TypeOrmModule.forFeature([UsersRepository]),
        TypeOrmModule.forFeature([SendEmailRepository]),
        TypeOrmModule.forFeature([EmailNotifierRepository]),
        JwtModule.registerAsync({
            useClass: JwtConfigService
        }),
        MailerModule.forRoot({
            transport: {
                host: process.env.EMAIL_HOST,
                port: parseInt(process.env.EMAIL_PORT),
                secure: true,
                auth: {
                    user: process.env.EMAIL_USER,
                    pass: process.env.EMAIL_PASS
                }
            },
            defaults: {
                from: `"${process.env.EMAIL_SENDER_NAME}" <${process.env.EMAIL_SENDER_MAIL}>`
            },
            template: {
                dir: __dirname + "/templates/**/*",
                adapter: new HandlebarsAdapter(),
                options: {
                    strict: true
                }
            }
        }),
        UsersModule,
        AuthModule,
        EmailNotifierModule,
        FileUploadsModule,
        SendEmailModule,
        MailSenderModule,
        SpacesModule,
        BillingAddressModule,
        ShippingAddressModule,
        ContactPageCmsModule,
        LandingPageCmsModule,
        AboutPageCmsModule,
        FAQPageCmsModule,
        CareerPageCmsModule,
        HeaderCmsModule,
        FooterCmsModule,
        HomePageSectionTwoCmsModule,
        HomePageSectionThreeCmsModule,
        HomePageSectionFourCmsModule,
        HomePageCommonBannerCmsModule,
        NewDropBannerCmsModule,
        HomePageSectionSevenCmsModule,
        PrivacyPolicyCmsModule,
        TermsOfServiceCmsModule,
        CookiesSettingsCmsModule,
        StoreModule,
        AboutPageSectionTwoModule,
        HomePageSectionOneModule,
        FAQModule,
        CareerModule,
        SocialPackModule,
        SiteFrontendModule,
        CareerApplicantModule,
        AboutPageUiModule,
        TermsConditionPageUiModule,
        PrivacyPolicyPageUiModule,
        CookiesSettingsPageUiModule,
        ContactPageUiModule,
        CareerPageUiModule,
        CareerDetailsPageUiModule,
        DutchiePlusProductModule,
        DutchiePlusRetailerModule,
        FaqPageUiModule,
        DutchiePlusSpecialsModule,
        StoreCmsModule,
        DutchiePlusCheckoutModule,
        DutchiePlusOrderModule,
        DutchiePlusCustomerModule,
        BlogCategoryModule,
        BlogTagModule,
        BlogPostModule,
        BlogPostTagsModule,
        BlogRelatedPostsModule,
        LandingPageUiModule,
        ArticlePageUiModule,
        ArticleDetailsPageUiModule,
        PressPageUiModule,
        PressDetailsPageUiModule,
        AgeVerificationCmsModule,
        FeedbackModule,
        PressReleaseModule,
        ContactMessageModule,
        ArticlePageCmsModule,
        PressReleaseCmsModule,
        ServiceTypeCmsModule,
        CareerDepartmentModule,
        CartCmsModule,
        SchedulerModule,
        ProductCategoryModule,
        QuizModule,
        QuizPageCmsModule,
        HomePageSectionEightCmsModule,
        HomePageSectionNineCmsModule,
        HomePageSectionFourSliderModule,
        HomePageSectionFiveCmsModule,
        HighDealsCmsModule,
        DiscoverCmsModule,
        ProductReviewModule,
        ReserveTimeCmsModule,
        RelatedProductCmsModule,
        HowToEnjoyCmsModule,
        ProductServiceModule,
        HomePageSectionTwoModule,
        HomePageNewDropsBannerModule,
        HomePageSectionEightModule,
        HomePageSectionFiveModule,
        FeaturedBrandModule,
        RetailerServiceModule,
        OrderServiceModule,
        ArticleDetailsCmsModule,
        SectionOneModule,
        SectionTwoBottomModule,
        SectionThreeModule,
        SectionTwoTopModule,
        AlpineiqModule,
        PageTitleCmsModule,
        PageMetaCmsModule,
        HeaderBannerCmsModule,
        InstagramSectionCmsModule,
        ProductDetailsPageUiModule,
        StaticSiteMapCmsModule,
        productDetailsPageMetaModule,
        RobotCmsModule,
        PageSchemaModule,
        StepsSectionCmsModule,
        BenefitsSectionCmsModule,
        BenefitsModalModule,
        AboutPageHeaderCmsModule,
        AboutPageSectionTwoCmsModule,
        AboutPageSectionThreeCmsModule,
        AboutPageSectionOneCmsModule,
        TopTickerComponentUiModule,
        BenefitsSectionLearnMoreModule,
        BenefitsContentModule,
        HomePageUiModule,
        HeaderBannerCmsModule,
        UserPageBannerCmsModule,
        UserBannerComponentUiModule,
        HomePageSubNavModule,
        ArticleCategoryModule,
        PressReleaseCategoryModule,
        ContactReasonModule,
        JarsPlusPageUiModule,
        StateWiseProductCategoryModule,
        CartCounterCmsModule,
        HomePageMobileCategoryCmsModule,
        LoginPageCmsModule,
        RegisterPageCmsModule,
        LoginPageUiModule,
        RegisterPageUiModule,
        ShopPageBannerCmsModule,
        ShopBannerComponentUiModule,
        IheartjaneModule,
        PickupDeliveryCmsModule,
    ],
    controllers: [AppController],
    providers: [
        AppService,
        UsersService,
        SendEmailService,
        FileUploadsService,
        DoSpacesService,
        DoSpacesServicerovider
    ]
})
export class AppModule {
}
