import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { AboutPageSectionTwoCmsService } from "./about-page-section-two-cms.service";
import { UpdateAboutPageSectionTwoCmsDto } from "./dto/update-about-page-section-two-cms.dto";

@Controller({ path: "about-page-section-two-cms", version: Constants.API_VERSION_1 })

export class AboutPageSectionTwoCmsController {
    constructor(private readonly service: AboutPageSectionTwoCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
      [
          { name: "imageOne", maxCount: 1 },
          { name: "imageTwo", maxCount: 1 },
          { name: "imageThree", maxCount: 1 }
      ]
    ))
    updateOrCreateData(
      @Body() dto: UpdateAboutPageSectionTwoCmsDto,
      @UploadedFiles() files: {
          imageOne: UploadedMulterFileI,
          imageTwo: UploadedMulterFileI,
          imageThree: UploadedMulterFileI,
      }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
