import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { BenefitsSectionCmsRepository } from "./benefits-section-cms.repository";
import { UpdateBenefitsSectionCmsDto } from "./dto/update-benefits-section-cms.dto";
import { BenefitsSectionCmsEntity } from "./entities/benefits-section-cms.entity";
import { BenefitsContentRepository } from "../../benefits-content/benefits-content.repository";
import {
    BenefitsSectionLearnMoreRepository
} from "../../benefits-section-learn-more/benefits-section-learn-more.repository";

@Injectable()
export class BenefitsSectionCmsService {
    constructor(
      @InjectRepository(BenefitsSectionCmsRepository)
      private readonly repository: BenefitsSectionCmsRepository,
      private readonly doSpaceService: DoSpacesService,
      @InjectRepository(BenefitsContentRepository)
      private readonly benefitsContentRepo: BenefitsContentRepository,
      @InjectRepository(BenefitsSectionLearnMoreRepository)
      private readonly benefitsSectionLearnMoreRepo: BenefitsSectionLearnMoreRepository
    ) {
    }

    async updateOrCreateData(
      dto: UpdateBenefitsSectionCmsDto,
      files: {
          imageOne: UploadedMulterFileI,
          imageTwo: UploadedMulterFileI,
          imageThree: UploadedMulterFileI,
      }
    ): Promise<BenefitsSectionCmsEntity | Error> {
        if (files && files.imageOne) {
            const imageOne: any = await this.doSpaceService.uploadFile(files.imageOne[0], "BenefitsSectionCms/");
            dto.imageOne = imageOne;
        }

        if (files && files.imageTwo) {
            const imageTwo: any = await this.doSpaceService.uploadFile(files.imageTwo[0], "BenefitsSectionCms/");
            dto.imageTwo = imageTwo;
        }

        if (files && files.imageThree) {
            const imageThree: any = await this.doSpaceService.uploadFile(files.imageThree[0], "BenefitsSectionCms/");
            dto.imageThree = imageThree;
        }

        const isExists = await this.repository.find({ isDeleted: false });
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                  Constants.NOT_FOUND,
                  HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                  Constants.UPDATE_FAILED,
                  HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<BenefitsSectionCmsEntity[] | Error> {
        const data = await this.repository.findAll();
        const benefitsContentData = await this.benefitsContentRepo.findByFilterQuery({});
        let benefitsContent = [];
        for (let i = 0; i < Object.keys(benefitsContentData).length; i++) {
            benefitsContentData[i].benefitsContentLearnMore = await this.benefitsSectionLearnMoreRepo.findByFilterQuery({
                benefitsId: benefitsContentData[i].id
            });
            benefitsContent.push(benefitsContentData[i]);
        }

        const response = {
            data,
            benefitsContent
        };
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", response);
    }
}