import { HttpException, HttpStatus, Injectable, NotFoundException } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { HomePageSectionTwoCmsRepository } from "./home-page-section-two-cms.repository";
import { UpdateHomePageSectionTwoCmsDto } from "./dto/update-home-page-section-two-cms.dto";
import { HomePageSectionTwoCms } from "./entities/home-page-section-two-cms.entity";

@Injectable()
export class HomePageSectionTwoCmsService {
    constructor(
      @InjectRepository(HomePageSectionTwoCmsRepository)
      private readonly repository: HomePageSectionTwoCmsRepository
    ) {
    }

    async updateOrCreateData(
      dto: UpdateHomePageSectionTwoCmsDto
    ): Promise<HomePageSectionTwoCms | Error> {
        const isExists = await this.repository.find({
            // stateCode: dto.stateCode,
            isDeleted: false
        });
        // if (dto.isDefault) {
        //     // Retrieve all entities
        //     const entities = await this.repository.find();

        //     // Update the isDefault property for each entity
        //     for (const entity of entities) {
        //         const updateData = await this.repository.update(entity.id, { isDefault: false });
        //     }
        // }
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                  Constants.NOT_FOUND,
                  HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                  Constants.UPDATE_FAILED,
                  HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<HomePageSectionTwoCms[] | Error> {
        const data = await this.repository.find({
            // stateCode: stateCode,
            isDeleted: false
        });
        if (!data) {
            throw new NotFoundException(Constants.NOT_FOUND);
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}