import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { SectionTwoTopDto } from "./dto/section-two-top.dto";
import { SectionTwoTopRepository } from "./section-three.repository";
import { InjectRepository } from "@nestjs/typeorm";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { SectionTwoTop } from "./entities/section-two-top.entity";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";

@Injectable()
export class SectionTwoTopService {
    constructor(
      @InjectRepository(SectionTwoTopRepository)
      private readonly repository: SectionTwoTopRepository,
      private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
      dto: SectionTwoTopDto,
      files: {
          video: UploadedMulterFileI
      }
    ): Promise<SectionTwoTop | Error> {
        if (files && files.video) {
            const video: any = await this.doSpaceService.uploadFile(files.video[0], "SectionTwoTopCMS/");
            dto.video = video;
        }

        const isExists = await this.repository.find({ isDeleted: false });
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                  Constants.NOT_FOUND,
                  HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                  Constants.UPDATE_FAILED,
                  HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<SectionTwoTop[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(Constants.NOT_FOUND, HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}
