import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { StepsSectionCmsService } from "./steps-section-cms.service";
import { UpdateStepsSectionCmsDto } from "./dto/update-steps-section-cms.dto";

@Controller({ path: "steps-section-cms", version: Constants.API_VERSION_1 })

export class StepsSectionCmsController {
    constructor(private readonly service: StepsSectionCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
      [
          { name: "countOneImage", maxCount: 1 },
          { name: "countTwoImage", maxCount: 1 },
          { name: "countThreeImage", maxCount: 1 }
      ]
    ))
    updateOrCreateData(
      @Body() dto: UpdateStepsSectionCmsDto,
      @UploadedFiles() files: {
          countOneImage: UploadedMulterFileI,
          countTwoImage: UploadedMulterFileI,
          countThreeImage: UploadedMulterFileI,
      }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
