import { EntityRepository, getConnection, Repository } from "typeorm";
import { UpdateArticleCategoryDto } from "./dto/update-article-category.dto";
import { ArticleCategoryEntity } from "./entities/article-category.entity";
import { BaseArticleCategoryDto } from "./dto/base-article-category.dto";

@EntityRepository(ArticleCategoryEntity)
export class ArticleCategoryRepository extends Repository<ArticleCategoryEntity> {

    async createEntity(dto: BaseArticleCategoryDto): Promise<ArticleCategoryEntity | Error> {
        try {
            const entity = this.create({
                title: dto.title,
                imageOne: dto.imageOne,
                imageTwo: dto.imageTwo,
                isShowNav: dto.isShowNav
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async updateEntity(dto: UpdateArticleCategoryDto, id: string): Promise<ArticleCategoryEntity | Error> {
        try {
            await this.update(id, {
                title: dto.title,
                imageOne: dto.imageOne,
                imageTwo: dto.imageTwo,
                isShowNav: dto.isShowNav
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findAll(): Promise<ArticleCategoryEntity[] | Error> {
        try {
            return await this.find({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<ArticleCategoryEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
              .createQueryBuilder()
              .update(ArticleCategoryEntity)
              .set({ isDeleted: true })
              .where("id = :id", { id: id })
              .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}