import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateCareerApplicantDto } from "./dto/create-career-applicant.dto";
import { CareerApplicant } from "./entities/career-applicant.entity";

@EntityRepository(CareerApplicant)
export class CareerApplicantRepository extends Repository<CareerApplicant> {
    async createEntity(dto: CreateCareerApplicantDto): Promise<CareerApplicant | Error> {
        try {
            const {
                firstName,
                lastName,
                email,
                contactNumber,
                contactType,
                preferredCommunicationMethod,
                applicantCommunicationPolicy,
                termsAndCondition
            } = dto;
            const entity = this.create({
                firstName,
                lastName,
                email,
                contactNumber,
                contactType,
                preferredCommunicationMethod,
                applicantCommunicationPolicy,
                termsAndCondition
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<CareerApplicant | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<CareerApplicant[] | Error> {
        try {
            return await this.find({
                where: {
                    ...query,
                    isDeleted: false
                },
                order: {
                    createdAt: "DESC"
                }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
              .createQueryBuilder()
              .update(CareerApplicant)
              .set({ isDeleted: true })
              .where("id = :id", { id: id })
              .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }

    async countAllQuery(): Promise<any | Error> {
        try {
            return await this.count({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }
}