import { EntityRepository, Repository } from "typeorm";
import { UpdatePressPageUiDto } from "./dto/update-press-page-ui.dto";
import { PressPageUI } from "./entities/press-page-ui.entity";

@EntityRepository(PressPageUI)
export class PressPageUiRepository extends Repository<PressPageUI> {

    async createEntity(dto: UpdatePressPageUiDto): Promise<PressPageUI | Error> {
        try {
            const entity = this.create({
                pageBackgroundColor: dto.pageBackgroundColor,
                titleFontColor: dto.titleFontColor,
                subTitleFontColor: dto.subTitleFontColor,
                buttonBackgroundColor: dto.buttonBackgroundColor,
                buttonFontColor: dto.buttonFontColor
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async updateEntity(dto: UpdatePressPageUiDto, id: string): Promise<PressPageUI | Error> {
        try {
            await this.update(id, {
                pageBackgroundColor: dto.pageBackgroundColor,
                titleFontColor: dto.titleFontColor,
                subTitleFontColor: dto.subTitleFontColor,
                buttonBackgroundColor: dto.buttonBackgroundColor,
                buttonFontColor: dto.buttonFontColor
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findAll(): Promise<PressPageUI[] | Error> {
        try {
            return await this.find({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }
}