import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateContactReasonDto } from "./dto/create-contact-reason.dto";
import { UpdateContactReasonDto } from "./dto/update-contact-reason.dto";
import { ContactReason } from "./entities/contact-reason.entity";

@EntityRepository(ContactReason)
export class ContactReasonRepository extends Repository<ContactReason> {
    async createEntity(dto: CreateContactReasonDto): Promise<ContactReason | Error> {
        try {
            const entity = this.create({ ...dto });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<ContactReason | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateContactReasonDto): Promise<ContactReason | Error> {
        try {
            await this.update(id, { 
                stateCode: dto.stateCode,
                stateName: dto.stateName,
                contactReasonName: dto.contactReasonName,
                contactEmail: dto.contactEmail
             });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<ContactReason[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(ContactReason)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}