import { HttpException, HttpStatus, Injectable, NotFoundException } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UploadedMulterFileI } from "../SpacesModule/SpacesService";
import { DoSpacesService } from "../SpacesModule/SpacesService/doSpacesService";
import { HomePageSectionOneRepository } from "./home-page-section-one.repository";
import { CreateHomePageSectionOneDto } from "./dto/create-home-page-section-one.dto";
import { UpdateHomePageSectionOneDto } from "./dto/update-home-page-section-one.dto";
import { HomePageSectionOne } from "./entities/home-page-section-one.entity";

@Injectable()
export class HomePageSectionOneService {
    constructor(
      @InjectRepository(HomePageSectionOneRepository)
      private readonly repository: HomePageSectionOneRepository,
      private readonly doSpaceService: DoSpacesService
    ) {
    }

    // async makeDefault(dto: any): Promise<any | Error> {
    //     // Retrieve all entities
    //     const entities = await this.repository.find();

    //     // Update the isDefault property for each entity
    //     for (const entity of entities) {
    //         const updateData = await this.repository.update(entity.id, { isDefault: false });
    //     }
    //     ;

    //     // retrive data using state code
    //     const data = await this.repository.find({
    //         stateCode: dto.stateCode,
    //         isDeleted: false
    //     });

    //     for (const entity of data) {
    //         const updateData = await this.repository.update(entity.id, { isDefault: true });
    //     }
    //     ;

    //     const finalData = await this.repository.find({
    //         stateCode: dto.stateCode,
    //         isDeleted: false
    //     });

    //     return ResponseUtils.successResponseHandler(200, "Data updated successfully", "data", finalData);
    // }

    async create(dto: CreateHomePageSectionOneDto, files: {
        image: UploadedMulterFileI
    }): Promise<HomePageSectionOne | Error> {
        if (files && files.image) {
            const image: any = await this.doSpaceService.uploadFile(files.image[0], "HomePageSectionOne/");
            dto.image = image;
        }
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
              Constants.CREATE_FAILED,
              HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Data created successfully", "data", data);
    }

    async update(
      id: string,
      dto: UpdateHomePageSectionOneDto,
      files: {
          image: UploadedMulterFileI,
      }
    ): Promise<HomePageSectionOne | Error> {
        const res: any = await this.repository.findOneEntity(id);
        if (!res) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        if (files && files.image) {
            const image: any = await this.doSpaceService.uploadFile(files.image[0], "HomePageSectionOne/");
            dto.image = image;
        }
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
              Constants.UPDATE_FAILED,
              HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data updated successfully", "data", data);
    }

    async findAll(): Promise<HomePageSectionOne[] | Error> {
        const data = await this.repository.find({ isDeleted: false });
        if (!data) {
            throw new NotFoundException(Constants.NOT_FOUND);
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<HomePageSectionOne[] | Error> {
        const data = await this.repository.findByFilterQuery({ id: id });
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully");
    }
}
