import { Injectable } from '@nestjs/common';
import { CreateIheartjaneDto } from './dto/create-iheartjane.dto';
import { UpdateIheartjaneDto } from './dto/update-iheartjane.dto';
import { iHeartJaneAuthentication } from 'src/helper/iheartjane-client-helper';
import axios from 'axios';

@Injectable()
export class IheartjaneService {


  async authentication(): Promise<any | Error> {
    try {
      const data = await iHeartJaneAuthentication();
      return data;
    } catch (error) {
      console.log(error);
      return error;
    }
  }

  async allStore(): Promise<any | Error> {
    try {
      const authentication: any = await iHeartJaneAuthentication();
      if (authentication.access_token) {
        const apiUrl = `${process.env.IHEARTJANE_API_HOST}/api/roots/store_operations_api/v1/stores`;
        const config = {
          headers: {
            "Content-Type": "application/json",
            "Authorization": `Bearer ${authentication.access_token}`
          }
        };
        const response = await axios.get(apiUrl, config);
        if (response.status === 200) {
          return response.data;
        }
      }
    } catch (error) {
      console.log(error);
      return error;
    }
  }

  async findOneStore(id: string): Promise<any | Error> {
    try {
      const authentication: any = await iHeartJaneAuthentication();
      if (authentication.access_token) {
        const apiUrl = `${process.env.IHEARTJANE_API_HOST}/api/roots/store_operations_api/v1/stores/${id}`;
        const config = {
          headers: {
            "Content-Type": "application/json",
            "Authorization": `Bearer ${authentication.access_token}`
          }
        };
        const response = await axios.get(apiUrl, config);
        if (response.status === 200) {
          return response.data;
        }
      }
    } catch (error) {
      console.log(error);
      return error;
    }
  }

  async allSpecials(id: string): Promise<any | Error> {
    try {
      const authentication: any = await iHeartJaneAuthentication();
      if (authentication.access_token) {
        const apiUrl = `${process.env.IHEARTJANE_API_HOST}/api/roots/store_operations_api/v1/stores/${id}/specials`;
        const config = {
          headers: {
            "Content-Type": "application/json",
            "Authorization": `Bearer ${authentication.access_token}`
          }
        };
        const response = await axios.get(apiUrl, config);
        if (response.status === 200) {
          return response.data;
        }
      }
    } catch (error) {
      console.log(error);
      return error;
    }
  }

  async allProducts(paginationId: number, pageSize: number): Promise<any | Error> {
    try {
      const authentication: any = await iHeartJaneAuthentication();
      if (authentication.access_token) {
        const apiUrl = `${process.env.IHEARTJANE_API_HOST}/api/roots/store_operations_api/v1/menu_products`;
        const config = {
          headers: {
            "Content-Type": "application/json",
            "Authorization": `Bearer ${authentication.access_token}`
          },
          params: {
            pagination_id: paginationId,
            page_size: pageSize
          }
        };
        const response = await axios.get(apiUrl, config);
        if (response.status === 200) {
          return response.data;
        }
      }
    } catch (error) {
      console.log(error);
      return error;
    }
  }

  async findProductSlugOrProductId(slugOrProductId: string, storeIds: any): Promise<any | Error> {
    try {
      const authentication: any = await iHeartJaneAuthentication();
      if (authentication.access_token) {
        const apiUrl = `${process.env.IHEARTJANE_API_HOST}/api/roots/store_operations_api/v1/menu_products/menu_product_slug`;
        const config = {
          headers: {
            "Content-Type": "application/json",
            "Authorization": `Bearer ${authentication.access_token}`
          },
          params: {
            slug_or_product_id: slugOrProductId,
            store_ids: storeIds
          }
        };
        const response = await axios.get(apiUrl, config);
        if (response.status === 200) {
          return response.data;
        }
      }
    } catch (error) {
      console.log(error);
      return error;
    }
  }
}
