import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { PressReleaseCategoryRepository } from "./press-release-category.repository";
import { BasePressReleaseCategoryDto } from "./dto/base-press-release-category.dto";
import { PressReleaseCategoryEntity } from "./entities/press-release-category.entity";
import { UpdatePressReleaseCategoryDto } from "./dto/update-press-release-category.dto";

@Injectable()
export class PressReleaseCategoryService {
    constructor(
      @InjectRepository(PressReleaseCategoryRepository)
      private readonly repository: PressReleaseCategoryRepository,
      private readonly doSpaceService: DoSpacesService
    ) {
    }

    async create(dto: BasePressReleaseCategoryDto, files: {
        imageOne: UploadedMulterFileI,
        imageTwo: UploadedMulterFileI,
    }): Promise<PressReleaseCategoryEntity | Error> {
        if (files && files.imageOne) {
            const imageOne: any = await this.doSpaceService.uploadFile(files.imageOne[0], "HomePageSubNavCms/");
            dto.imageOne = imageOne;
        }

        if (files && files.imageTwo) {
            const imageTwo: any = await this.doSpaceService.uploadFile(files.imageTwo[0], "HomePageSubNavCms/");
            dto.imageTwo = imageTwo;
        }
        const isShowNav: any = dto.isShowNav;
        dto.isShowNav = isShowNav === 'true';
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
              Constants.CREATE_FAILED,
              HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Data created successfully", "data", data);
    }

    async update(
      id: string,
      dto: UpdatePressReleaseCategoryDto,
      files: {
          imageOne: UploadedMulterFileI,
          imageTwo: UploadedMulterFileI,
      }
    ): Promise<PressReleaseCategoryEntity | Error> {
        const res: any = await this.repository.findOneEntity(id);
        if (!res) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        if (files && files.imageOne) {
            const imageOne: any = await this.doSpaceService.uploadFile(files.imageOne[0], "HomePageSubNavCms/");
            dto.imageOne = imageOne;
        }

        if (files && files.imageTwo) {
            const imageTwo: any = await this.doSpaceService.uploadFile(files.imageTwo[0], "HomePageSubNavCms/");
            dto.imageTwo = imageTwo;
        }
        const isShowNav: any = dto.isShowNav;
        dto.isShowNav = isShowNav === 'true';
        const data = await this.repository.updateEntity(dto, id);
        if (!data) {
            throw new HttpException(
              Constants.UPDATE_FAILED,
              HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data updated successfully", "data", data);
    }

    async findAll(): Promise<PressReleaseCategoryEntity[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<PressReleaseCategoryEntity[] | Error> {
        const data = await this.repository.findOne({ id: id });
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully");
    }
}